document.addEventListener("DOMContentLoaded", function() {
    fetchUserIdFromSession();
    const form = document.querySelector('form');
    if (form) {
        form.addEventListener('submit', function(e) {
            e.preventDefault(); // Prevent the default form submission
            const formData = new FormData(form); // Gather form data
            submitProfileUpdate(formData); // Call the external function
        });
    }
});

var user_id;

function fetchUserIdFromSession() {
    fetch('/get-user-id', {
        method: 'GET',
        credentials: 'include', // Ensures cookies, e.g., session ID, are sent with the request
    })
    .then(response => {
        if (!response.ok) {
            throw new Error('Failed to fetch user ID. Server responded with status: ' + response.status);
        }
        return response.json();
    })
    .then(data => {
        if (data.user_id !== undefined) {
            user_id = data.user_id;
            console.log('User ID:', user_id);
            fetchUserData(user_id);
        } else {
            console.error('User is not authenticated or session data is missing.');
        }
    })
    .catch(error => console.error('Error fetching user session data:', error));
}

function fetchUserData(userId) {
    const apiUrl = `/api/user-data/${userId}`;

    fetch(apiUrl)
        .then(response => {
            if (!response.ok) {
                throw new Error('Failed to fetch user data. Server responded with status: ' + response.status);
            }
            return response.json();
        })
        .then(userData => {
            updateUserUI({
                username: userData.username,
                first_name: userData.first_name,
                last_name: userData.last_name,
            });
            console.log('Fetched User Data:', userData);
        })
        .catch(error => {
            console.error('Error fetching user data:', error);
        });
}

function updateUserUI(userData) {
    updateField('username', userData.username, 'Enter new username');
    updateField('first_name', userData.first_name, 'Enter first name');
    updateField('last_name', userData.last_name, 'Enter last name');
}

function updateField(fieldName, value, placeholder) {
    const field = document.querySelector(`input[name="${fieldName}"]`);
    if (field) {
        field.placeholder = value || placeholder;
    }
}

function togglePasswordVisibility() {
    const passwordInput = document.getElementById('passwordInput');
    const toggleIcon = document.querySelector('.toggle-password');
    if (passwordInput.type === 'password') {
        passwordInput.type = 'text';
        toggleIcon.classList.replace('fa-eye', 'fa-eye-slash');
    } else {
        passwordInput.type = 'password';
        toggleIcon.classList.replace('fa-eye-slash', 'fa-eye');
    }
}

function submitProfileUpdate(formData) {
    fetch('/update-profile', {
        method: 'POST',
        body: formData,
        credentials: 'include' // Include cookies if needed for authentication
    })
    .then(response => {
        if (!response.ok) {
            throw new Error('Failed to update profile. Status code: ' + response.status);
        }
        return response.json();
    })
    .then(data => {
        // Display the success message
        alert('Password updated successfully! Redirecting to Log On Page in 3 seconds.');

        // Set a timer to redirect after 2 seconds
        setTimeout(() => {
            window.location.href = '/logout'; // Redirect to the dashboard
        }, 2000); // 2000 milliseconds = 2 seconds
    })
    .catch(error => {
        alert('Error updating profile: ' + error.message);
        console.error('Error:', error);
    });
}
