document.addEventListener('DOMContentLoaded', function() {
    // Extract complianceType from the query string
    const urlParams = new URLSearchParams(window.location.search);
    const complianceType = urlParams.get('complianceType');

    // Check for complianceType
    if (!complianceType) {
        console.error('Compliance Type is missing');
        // Handle missing complianceType appropriately
        return; // Exit the function if complianceType is missing
    }

    // Fetch and display chapter data
    fetch(`/api/get-chapters-data?complianceType=${complianceType}`)
        .then(response => response.json())
        .then(data => {
            if (!Array.isArray(data)) {
                throw new Error('Chapter data is not an array');
            }
            const chapterHeadings = document.getElementById('chapterHeadings');
            data.forEach(chapter => {
                const chapterHeading = document.createElement('h2');
                chapterHeading.textContent = `Chapter ${chapter.chapterNumber}: ${chapter.chapterTitle}`;
                chapterHeadings.appendChild(chapterHeading);
            });
            console.log('Chapter data received:', data); // Log the received chapter data
        })
        .catch(error => console.error('Error fetching chapter data:', error));

    // Fetch and display compliance data
    fetch(`/api/compliance-data?complianceType=${complianceType}`)
        .then(response => response.json())
        .then(data => {
            if (!Array.isArray(data)) {
                throw new Error('Compliance data is not an array');
            }
            const complianceTableBody = document.getElementById('complianceTableBody');
            complianceTableBody.innerHTML = ''; // Clear existing table data
            data.forEach(item => {
                const row = document.createElement('tr');
                row.innerHTML = `
                    <td>${item.controlId}</td>
                    <td>${item.controlText}</td>
                    <td>${item.requirements}</td>
                    <td>${item.explanation}</td>
                    <td><input type='text' value='${item.notes || ''}' /></td>
                `;
                complianceTableBody.appendChild(row);
            });
            console.log('Compliance data received:', data); // Log the received compliance data
        })
        .catch(error => console.error('Error fetching compliance data:', error));

    // Save functionality
    const saveButton = document.getElementById('saveButton');
    saveButton.addEventListener('click', () => {
        const updatedData = Array.from(document.querySelectorAll('#complianceTableBody tr')).map(row => {
            const cells = row.querySelectorAll('td');
            return {
                controlId: cells[0].textContent.trim(),
                notes: cells[4].querySelector('input').value,
                projectId: projectId, // Assuming projectId is available in the scope
                complianceType: complianceType
            };
        });

        fetch('/api/save-compliance-data', {
            method: 'POST',
            headers: {
                'Content-Type': 'application/json',
            },
            body: JSON.stringify(updatedData),
        })
        .then(response => {
            if (!response.ok) {
                throw new Error('Failed to save compliance data');
            }
            return response.json();
        })
        .then(data => {
            console.log('Save successful:', data);
            alert('Compliance data saved successfully.'); // Provide user feedback
        })
        .catch(error => console.error('Error saving compliance data:', error));
    });
});
